summary | shortlog | log | commit | commitdiff | tree
raw | patch | inline | side by side (parent: 965537f)
raw | patch | inline | side by side (parent: 965537f)
author | Jonas Fonseca <fonseca@diku.dk> | |
Mon, 29 May 2006 01:01:27 +0000 (03:01 +0200) | ||
committer | Jonas Fonseca <fonseca@antimatter.localdomain> | |
Mon, 29 May 2006 01:01:27 +0000 (03:01 +0200) |
tig.c | patch | blob | history |
index 94af086fc718fa1f6eb6d985292a2c3581a45617..c7a784251edb7779f49c9a8a9b38d6921f1cda4b 100644 (file)
--- a/tig.c
+++ b/tig.c
/**
* FILES
* -----
- * '~/.tig'::
+ * '~/.tigrc'::
* User configuration file. See "<<config-options, Configuration options>>"
* section for examples.
*
* [[config-options]]
* User Configuration file
* -----------------------
* You can permanently set an option by putting it in the `~/.tig` file.
* The file consists of a series of 'commands'. Each
* line of the file may contain only one command.
*
config_errors = FALSE;
if (!home ||
- snprintf(buf, sizeof(buf), "%s/.tig", home) >= sizeof(buf))
+ snprintf(buf, sizeof(buf), "%s/.tigrc", home) >= sizeof(buf))
return ERR;
/* It's ok that the file doesn't exist. */
@@
* User Configuration file
* -----------------------
- * You can permanently set an option by putting it in the `~/.tig` file.
+ * You can permanently set an option by putting it in the `~/.tigrc` file.
* The file consists of a series of 'commands'. Each
* line of the file may contain only one command.